@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import os
+import sys
 import textwrap
 import typing as t
 
@@ -23,6 +24,11 @@ from ..transforms import TRANSFORM_LIBRARY
 from .param_types import CommaDelimitedList, LazyBinaryReadFile, ValidatorClassName
 from .parse_result import ParseResult, SchemaLoadingMode
 
+if sys.version_info >= (3, 8):
+    from typing import Literal
+else:
+    from typing_extensions import Literal
+
 BUILTIN_SCHEMA_NAMES = [f"vendor.{k}" for k in SCHEMA_CATALOG.keys()] + [
     f"custom.{k}" for k in CUSTOM_SCHEMA_NAMES
 ]
@@ -232,16 +238,16 @@ def main(
     no_cache: bool,
     cache_filename: str | None,
     disable_formats: tuple[list[str], ...],
-    format_regex: str,
-    default_filetype: str,
-    traceback_mode: str,
-    data_transform: str | None,
+    format_regex: Literal["python", "default"],
+    default_filetype: Literal["json", "yaml", "toml", "json5"],
+    traceback_mode: Literal["full", "short"],
+    data_transform: Literal["azure-pipelines", "gitlab-ci"] | None,
     fill_defaults: bool,
     validator_class: type[jsonschema.protocols.Validator] | None,
-    output_format: str,
+    output_format: Literal["text", "json"],
     verbose: int,
     quiet: int,
-    instancefiles: tuple[t.BinaryIO, ...],
+    instancefiles: tuple[t.IO[bytes], ...],
 ) -> None:
     args = ParseResult()
 
